@@ -1,4 +1,4 @@
-# Copyright 2023 The EASYDEL Author @erfanzar (Erfan Zare Chavoshi).
+# Copyright 2025 The EasyDeL Author @erfanzar (Erfan Zare Chavoshi).
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,29 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from ._eopod_cli import main
 
-from ._eopod_cli import (
-	show_config,
-	errors,
-	history,
-	run,
-	configure,
-	main,
-	check_background,
-	kill,
-	async_command,
-)
-
-__version__ = "0.0.15"
-
-__all__ = (
-	"show_config",
-	"errors",
-	"history",
-	"run",
-	"configure",
-	"main",
-	"check_background",
-	"kill",
-	"async_command",
-)
+__all__ = ("main",)
+__version__ = "0.0.33"
